nessie\_client package
======================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pynessie.auth
   pynessie.conf

Submodules
----------

nessie\_client.cli module
-------------------------

.. automodule:: pynessie.cli
   :members:
   :undoc-members:
   :show-inheritance:

nessie\_client.error module
---------------------------

.. automodule:: pynessie.error
   :members:
   :undoc-members:
   :show-inheritance:

nessie\_client.model module
---------------------------

.. automodule:: pynessie.model
   :members:
   :undoc-members:
   :show-inheritance:

nessie\_client.nessie\_client module
------------------------------------

.. automodule:: pynessie.pynessie
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: pynessie
   :members:
   :undoc-members:
   :show-inheritance:
